@@ -2,6 +2,9 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, ClassVar
 
+from pdm import termui
+from pdm.cli.commands.base import BaseCommand
+from pdm.cli.options import dry_run_option
 from pdm.signals import post_install, post_lock
 from pdm.termui import Verbosity
 
@@ -13,6 +16,7 @@ from sync_pre_commit_lock.actions.sync_hooks import GenericLockedPackage, SyncPr
 from sync_pre_commit_lock.config import SyncPreCommitLockConfig, load_config
 
 if TYPE_CHECKING:
+    import argparse
     from collections.abc import Sequence
     from pathlib import Path
 
@@ -22,15 +26,19 @@ if TYPE_CHECKING:
     from pdm.project import Project
     from pdm.termui import UI
 
+    from sync_pre_commit_lock.pre_commit_config import PreCommitRepo
+
 
 class PDMPrinter(Printer):
-    def __init__(self, ui: UI, **_: Any):
+    success_list_token: str = f"[success]{termui.Emoji.SUCC}[/]"
+
+    def __init__(self, ui: UI, with_prefix: bool = True, **_: Any):
         self.ui = ui
-        self.plugin_prefix = "\\[sync-pre-commit-lock]"
+        self.plugin_prefix = "\\[sync-pre-commit-lock] " if with_prefix else ""
 
     def prefix_lines(self, msg: str) -> str:
         lines = msg.split("\n")
-        return "\n".join(f"{self.plugin_prefix} {line}" for line in lines)
+        return "\n".join(f"{self.plugin_prefix}{line}" for line in lines)
 
     def debug(self, msg: str) -> None:
         self.ui.echo(self.prefix_lines("[debug]" + msg + "[/debug]"), verbosity=Verbosity.DEBUG)
@@ -47,9 +55,32 @@ class PDMPrinter(Printer):
     def success(self, msg: str) -> None:
         self.ui.echo("[success]" + self.prefix_lines(msg) + "[/success]", verbosity=Verbosity.NORMAL)
 
+    def _format_repo_url(self, repo_url: str, package_name: str) -> str:
+        return repo_url.replace(package_name, f"[cyan][bold]{package_name}[/bold][/cyan]")
+
+    def list_updated_packages(self, packages: dict[str, tuple[PreCommitRepo, str]]) -> None:
+        """
+        Args:
+            packages: Dict of package name -> (repo, new_rev)
+        """
+        self.ui.display_columns(
+            [
+                (
+                    "[info]" + self.plugin_prefix + "[/info]" + " " + self.success_list_token,
+                    "[info]" + self._format_repo_url(repo[0].repo, package) + "[/info]",
+                    " ",
+                    "[error]" + repo[0].rev + "[/error]",
+                    "[info]" + "->" + "[/info]",
+                    "[green]" + repo[1] + "[/green]",
+                )
+                for package, repo in packages.items()
+            ]
+        )
+
 
 def register_pdm_plugin(core: Core) -> None:
     """Register the plugin to PDM Core."""
+    core.register_command(SyncPreCommitVersionsPDMCommand, "sync-pre-commit")
     printer = PDMPrinter(core.ui)
     printer.debug("Registered sync-pre-commit-lock plugin.")
 
@@ -73,12 +104,12 @@ def on_pdm_install_setup_pre_commit(
 
     if not plugin_config.automatically_install_hooks:
         printer.debug("Automatically installing pre-commit hooks is disabled. Skipping.")
-        return None
+        return
     action = PDMSetupPreCommitHooks(printer, dry_run=dry_run)
     file_path = project.root / plugin_config.pre_commit_config_file
     if not file_path.exists():
         printer.info("No pre-commit config file found, skipping pre-commit hook check")
-        return None
+        return
 
     printer.debug("Pre-commit config file found. Setting up pre-commit hooks...")
 
@@ -87,11 +118,11 @@ def on_pdm_install_setup_pre_commit(
 
 @post_lock.connect
 def on_pdm_lock_check_pre_commit(
-    project: Project, *, resolution: dict[str, Candidate], dry_run: bool, **kwargs: Any
+    project: Project, *, resolution: dict[str, Candidate], dry_run: bool, with_prefix: bool = True, **kwargs: Any
 ) -> None:
     project_root: Path = project.root
     plugin_config: SyncPreCommitLockConfig = load_config(project_root / project.PYPROJECT_FILENAME)
-    printer = PDMPrinter(project.core.ui)
+    printer = PDMPrinter(project.core.ui, with_prefix=with_prefix)
 
     file_path = project_root / plugin_config.pre_commit_config_file
     resolved_packages: dict[str, GenericLockedPackage] = {
@@ -105,3 +136,17 @@ def on_pdm_lock_check_pre_commit(
         dry_run=dry_run,
     )
     action.execute()
+
+
+class SyncPreCommitVersionsPDMCommand(BaseCommand):
+    """Sync `.pre-commit-config.yaml` hooks versions with the lockfile"""
+
+    # The class docstring acts as the description of the command, don't make it longer!
+
+    def add_arguments(self, parser: argparse.ArgumentParser) -> None:
+        dry_run_option.add_to_parser(parser)
+
+    def handle(self, project: Project, options: argparse.Namespace) -> None:
+        candidates = project.locked_repository.all_candidates
+
+        on_pdm_lock_check_pre_commit(project, resolution=candidates, dry_run=options.dry_run, with_prefix=False)
